@@ -52,7 +52,7 @@ logger = logging.getLogger(__name__)
 
 
 class Lineage:
-    """ Object used to interact with the `lineage` framework. """
+    """Object used to interact with the `lineage` framework."""
 
     def __init__(
         self,
@@ -61,7 +61,7 @@ class Lineage:
         parallelize=False,
         processes=os.cpu_count(),
     ):
-        """ Initialize a ``Lineage`` object.
+        """Initialize a ``Lineage`` object.
 
         Parameters
         ----------
@@ -80,7 +80,7 @@ class Lineage:
         self._parallelizer = Parallelizer(parallelize=parallelize, processes=processes)
 
     def create_individual(self, name, raw_data=(), **kwargs):
-        """ Initialize an individual in the context of the `lineage` framework.
+        """Initialize an individual in the context of the `lineage` framework.
 
         Parameters
         ----------
@@ -104,7 +104,7 @@ class Lineage:
         return Individual(name, raw_data, **kwargs)
 
     def download_example_datasets(self):
-        """ Download example datasets from `openSNP <https://opensnp.org>`_.
+        """Download example datasets from `openSNP <https://opensnp.org>`_.
 
         Per openSNP, "the data is donated into the public domain using `CC0 1.0
         <http://creativecommons.org/publicdomain/zero/1.0/>`_."
@@ -130,7 +130,7 @@ class Lineage:
     def find_discordant_snps(
         self, individual1, individual2, individual3=None, save_output=False
     ):
-        """ Find discordant SNPs between two or three individuals.
+        """Find discordant SNPs between two or three individuals.
 
         Parameters
         ----------
@@ -282,7 +282,7 @@ class Lineage:
         save_output=True,
         genetic_map="HapMap2",
     ):
-        """ Find the shared DNA between individuals.
+        """Find the shared DNA between individuals.
 
         Computes the genetic distance in centiMorgans (cMs) between SNPs using the specified genetic
         map. Applies thresholds to determine the shared DNA. Plots shared DNA. Optionally determines
@@ -500,6 +500,8 @@ class Lineage:
         if save_output:
             self._find_shared_dna_output_helper(
                 individuals,
+                cM_threshold,
+                snp_threshold,
                 one_chrom_shared_dna,
                 two_chrom_shared_dna,
                 one_chrom_shared_genes,
@@ -547,12 +549,24 @@ class Lineage:
     def _find_shared_dna_output_helper(
         self,
         individuals,
+        cM_threshold,
+        snp_threshold,
         one_chrom_shared_dna,
         two_chrom_shared_dna,
         one_chrom_shared_genes,
         two_chrom_shared_genes,
         genetic_map,
     ):
+        def output_csv(df, file, float_format="%.2f"):
+            save_df_as_csv(
+                df,
+                self._output_dir,
+                file,
+                comment=self._get_csv_header(),
+                prepend_info=False,
+                float_format=float_format,
+            )
+
         cytobands = self._resources.get_cytoBand_hg19()
 
         individuals_filename = ""
@@ -565,6 +579,11 @@ class Lineage:
         individuals_filename = individuals_filename[:-1]
         individuals_plot_title = individuals_plot_title[:-3]
 
+        cM = "{:.2f}".format(cM_threshold).replace(".", "p")
+        filename_details = (
+            f"{individuals_filename}_{cM}cM_{snp_threshold}snps_GRCh37_{genetic_map}"
+        )
+
         if create_dir(self._output_dir):
             plot_chromosomes(
                 one_chrom_shared_dna,
@@ -572,56 +591,36 @@ class Lineage:
                 cytobands,
                 os.path.join(
                     self._output_dir,
-                    f"shared_dna_{individuals_filename}_{genetic_map}.png",
+                    f"shared_dna_{filename_details}.png",
                 ),
                 f"{individuals_plot_title} shared DNA",
                 37,
             )
 
         if len(one_chrom_shared_dna) > 0:
-            file = (
-                f"shared_dna_one_chrom_{individuals_filename}_GRCh37_{genetic_map}.csv"
-            )
-            save_df_as_csv(
+            output_csv(
                 one_chrom_shared_dna,
-                self._output_dir,
-                file,
-                comment=self._get_csv_header(),
-                prepend_info=False,
-                float_format="%.2f",
+                f"shared_dna_one_chrom_{filename_details}.csv",
             )
 
         if len(two_chrom_shared_dna) > 0:
-            file = (
-                f"shared_dna_two_chroms_{individuals_filename}_GRCh37_{genetic_map}.csv"
-            )
-            save_df_as_csv(
+            output_csv(
                 two_chrom_shared_dna,
-                self._output_dir,
-                file,
-                comment=self._get_csv_header(),
-                prepend_info=False,
-                float_format="%.2f",
+                f"shared_dna_two_chroms_{filename_details}.csv",
             )
 
         if len(one_chrom_shared_genes) > 0:
-            file = f"shared_genes_one_chrom_{individuals_filename}_GRCh37_{genetic_map}.csv"
-            save_df_as_csv(
+            output_csv(
                 one_chrom_shared_genes,
-                self._output_dir,
-                file,
-                comment=self._get_csv_header(),
-                prepend_info=False,
+                f"shared_genes_one_chrom_{filename_details}.csv",
+                None,
             )
 
         if len(two_chrom_shared_genes) > 0:
-            file = f"shared_genes_two_chroms_{individuals_filename}_GRCh37_{genetic_map}.csv"
-            save_df_as_csv(
+            output_csv(
                 two_chrom_shared_genes,
-                self._output_dir,
-                file,
-                comment=self._get_csv_header(),
-                prepend_info=False,
+                f"shared_genes_two_chroms_{filename_details}.csv",
+                None,
             )
 
     def _find_shared_dna_return_helper(
@@ -696,7 +695,7 @@ class Lineage:
         return False
 
     def _compute_snp_distances(self, task):
-        """ Compute genetic distance in cMs between SNPs.
+        """Compute genetic distance in cMs between SNPs.
 
         Parameters
         ----------
@@ -712,7 +711,7 @@ class Lineage:
         temp = task["snps"]
 
         # merge genetic map for this chrom
-        temp = temp.append(genetic_map, ignore_index=False, sort=True)
+        temp = pd.concat([temp, genetic_map], ignore_index=False, sort=True)
 
         # sort based on pos
         temp = temp.sort_values("pos")
@@ -880,8 +879,6 @@ class Lineage:
 
     def _get_csv_header(self):
         return (
-            "# Generated by lineage v{}, https://pypi.org/project/lineage/\n"
-            "# Generated at {} UTC\n".format(
-                __version__, datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S")
-            )
+            f"# Generated by lineage v{__version__}; https://pypi.org/project/lineage/{os.linesep}"
+            f"# Generated at {datetime.datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S')} UTC{os.linesep}"
         )
