@@ -55,7 +55,13 @@ class TestLineage(BaseLineageTestCase):
         **kwargs,
     ):
         return {
-            chrom: pd.DataFrame({"pos": pos, "rate": rate, "map": map_cMs,}),
+            chrom: pd.DataFrame(
+                {
+                    "pos": pos,
+                    "rate": rate,
+                    "map": map_cMs,
+                }
+            ),
         }
 
     def _generate_test_cytoBand_hg19(self):
@@ -159,7 +165,8 @@ class TestLineage(BaseLineageTestCase):
             kg, kgXref = self._generate_test_gene_dfs(**kwargs)
 
             with patch(
-                genetic_map_patch, Mock(return_value=genetic_map),
+                genetic_map_patch,
+                Mock(return_value=genetic_map),
             ):
                 with patch(
                     "lineage.resources.Resources.get_cytoBand_hg19",
@@ -188,20 +195,13 @@ class TestLineage(BaseLineageTestCase):
     def _make_file_exist_assertions(
         self, inds, exist="all", genetic_map="HapMap2", output_dir="output"
     ):
+        filename_details = f"{inds}_0p75cM_1100snps_GRCh37_{genetic_map}"
         files = [
-            os.path.join(
-                output_dir, f"shared_dna_one_chrom_{inds}_GRCh37_{genetic_map}.csv"
-            ),
-            os.path.join(
-                output_dir, f"shared_dna_two_chroms_{inds}_GRCh37_{genetic_map}.csv"
-            ),
-            os.path.join(
-                output_dir, f"shared_genes_one_chrom_{inds}_GRCh37_{genetic_map}.csv"
-            ),
-            os.path.join(
-                output_dir, f"shared_genes_two_chroms_{inds}_GRCh37_{genetic_map}.csv"
-            ),
-            os.path.join(output_dir, f"shared_dna_{inds}_{genetic_map}.png"),
+            os.path.join(output_dir, f"shared_dna_one_chrom_{filename_details}.csv"),
+            os.path.join(output_dir, f"shared_dna_two_chroms_{filename_details}.csv"),
+            os.path.join(output_dir, f"shared_genes_one_chrom_{filename_details}.csv"),
+            os.path.join(output_dir, f"shared_genes_two_chroms_{filename_details}.csv"),
+            os.path.join(output_dir, f"shared_dna_{filename_details}.png"),
         ]
 
         if exist == "all":
@@ -579,10 +579,14 @@ class TestLineage(BaseLineageTestCase):
             assert len(d["one_chrom_discrepant_snps"]) == 0
             assert len(d["two_chrom_discrepant_snps"]) == 0
             np.testing.assert_allclose(
-                d["one_chrom_shared_dna"].loc[1]["cMs"], 202.022891, rtol=1e-5,
+                d["one_chrom_shared_dna"].loc[1]["cMs"],
+                202.022891,
+                rtol=1e-5,
             )
             np.testing.assert_allclose(
-                d["two_chrom_shared_dna"].loc[1]["cMs"], 20.837792, rtol=1e-3,
+                d["two_chrom_shared_dna"].loc[1]["cMs"],
+                20.837792,
+                rtol=1e-3,
             )
             self._make_file_exist_assertions("ind1_ind2", output_dir=tmpdir)
 
@@ -617,10 +621,14 @@ class TestLineage(BaseLineageTestCase):
             assert len(d["one_chrom_discrepant_snps"]) == 0
             assert len(d["two_chrom_discrepant_snps"]) == 0
             np.testing.assert_allclose(
-                d["one_chrom_shared_dna"].loc[1]["cMs"], 202.022891, rtol=1e-5,
+                d["one_chrom_shared_dna"].loc[1]["cMs"],
+                202.022891,
+                rtol=1e-5,
             )
             np.testing.assert_allclose(
-                d["two_chrom_shared_dna"].loc[1]["cMs"], 202.022891, rtol=1e-5,
+                d["two_chrom_shared_dna"].loc[1]["cMs"],
+                202.022891,
+                rtol=1e-5,
             )
             self._make_file_exist_assertions("ind1_ind2", output_dir=tmpdir)
 
